##
##  imagemagick.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_major 7.1.1
%define       V_minor 39
%define       V_dist  %{V_major}-%{V_minor}
%define       V_opkg  %{V_major}.%{V_minor}

#   package information
Name:         imagemagick
Summary:      Graphic Image Conversion Tool
URL:          http://www.imagemagick.org/
Vendor:       John Cristy
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Graphics
License:      ImageMagick
Version:      %{V_opkg}
Release:      20241008

#   package options
%option       with_perl   no

#   list of sources
Source0:      https://imagemagick.org/archive/ImageMagick-%{V_dist}.tar.gz
Patch0:       imagemagick.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make, gcc, grep, sed
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  tiff, jpeg, jasper, bzip2, zlib, png, flif, webp, freetype, fontconfig, lcms, liblqr, libxml, libiconv
PreReq:       tiff, jpeg, jasper, bzip2, zlib, png, flif, webp, freetype, fontconfig, lcms, liblqr, libxml, libiconv
%if "%{with_perl}" == "yes"
BuildPreReq:  perl, perl-openpkg
PreReq:       perl
%endif

%description
    ImageMagick is a robust collection of tools and libraries to read,
    write, and manipulate an image in many image formats (over 68 major
    formats) including popular formats like TIFF, JPEG, PNG, PDF, Photo
    CD, and GIF. With ImageMagick you can create images dynamically,
    making it suitable for Web applications. You can also resize,
    rotate, sharpen, color reduce, or add special effects to an image
    and save your completed work in the same or differing image format.
    Image processing operations are available from the command line, as
    well as through C, C++, and PERL-based programming interfaces.

%track
    prog imagemagick = {
        version   = %{V_dist}
        url       = https://imagemagick.org/script/download.php
        regex     = ImageMagick-(\d+\.\d+\.\d+-\d+)
    }

%prep
    %setup -q -n ImageMagick-%{V_dist}
    %patch -p0

%build
    %{l_shtool} subst \
        -e 's/^\(MagickLibSubdir="\)[^"]*\("\)/\1imagemagick\2/' \
        -e 's/\(-lxml2\)/\1 -liconv/' \
        configure
    %{l_shtool} subst \
        -e "s;\\(-lMagickCore\\);\\1 `pkg-config fontconfig --libs`;" \
        PerlMagick/Makefile.PL.in
    %{l_shtool} subst \
        -e 's;#!/usr/bin/sh;#!/bin/sh;' \
        config/ar-lib \
        config/compile \
        config/config.guess \
        config/config.sub \
        config/depcomp \
        config/install-sh \
        config/missing \
        config/mkinstalldirs \
        config/tap-driver.sh \
        config/test-driver
    cppflags=""
    case "%{l_platform -t}" in
        amd64-* ) cppflags="-DPNG_NO_ASSEMBLER_CODE" ;;
    esac
    CC="%{l_cc} -pthread" \
    CXX="%{l_cxx} -pthread" \
    CFLAGS="%{l_cflags -O} %{l_cppflags tiff}" \
    CPPFLAGS="%{l_cppflags tiff} $cppflags" \
    CXXFLAGS="%{l_cxxflags -O}" \
    LDFLAGS="%{l_ldflags}" \
    LIBS="-lz -liconv -lstdc++" \
    CONFIG_SHELL="%{l_bash}" \
    %{l_bash} ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --without-magick-plus-plus \
        --without-modules \
        --disable-dependency-tracking \
        --disable-shared \
        --with-zlib \
        --with-bzlib \
        --with-tiff \
        --with-jpeg \
        --with-png \
        --with-flif \
        --with-webp \
        --with-xml \
        --with-lcms \
        --with-lqr \
        --with-freetype \
        --without-djvu \
        --without-fftw \
        --without-gvc \
        --without-perl \
        --without-x \
        --without-threads
    %{l_make} %{l_mflags}
%if "%{with_perl}" == "yes"
    %{l_prefix}/bin/perl-openpkg prepare
    %{l_prefix}/bin/perl-openpkg -d PerlMagick configure build
%endif

%install

    %{l_make} %{l_mflags} install \
        AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"

%if "%{with_perl}" == "yes"
    %{l_prefix}/bin/perl-openpkg -d PerlMagick install
    %{l_prefix}/bin/perl-openpkg -F perl-openpkg-files fixate cleanup
%else
    >perl-openpkg-files
%endif

    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* 2>/dev/null || true
    ( cd $RPM_BUILD_ROOT%{l_prefix} || exit 1
      rm -f bin/cgimagick
      rm -f bin/iptcutil
      rm -f man/man4/miff.4
      rm -rf share/doc >/dev/null 2>&1 || true
      rm -rf share/ImageMagick-* >/dev/null 2>&1 || true
    ) || exit $?

    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} `cat perl-openpkg-files`

%files -f files

%clean

